package com.atguigu.daijia.driver.service.impl;

import com.atguigu.daijia.common.constant.RedisConstant;
import com.atguigu.daijia.common.result.Result;
import com.atguigu.daijia.common.util.AuthContextHolder;
import com.atguigu.daijia.driver.client.DriverInfoFeignClient;
import com.atguigu.daijia.driver.service.DriverService;
import com.atguigu.daijia.model.form.driver.UpdateDriverAuthInfoForm;
import com.atguigu.daijia.model.vo.driver.DriverAuthInfoVo;
import com.atguigu.daijia.model.vo.driver.DriverLoginVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

@Slf4j
@Service
public class DriverServiceImpl implements DriverService {

    @Autowired
    private DriverInfoFeignClient driverInfoFeignClient;

    @Autowired
    private RedisTemplate<Object, Object> redisTemplate;

    /**
     * 小程序司机登录
     *
     * @param code 唯一票据
     * @return openid
     */
    @Override
    public String login(String code) {
        Result<Long> longResult = driverInfoFeignClient.login(code);
        Long driverId = longResult.getData();
        String token = driverId.toString().replaceAll("-", "");

        // 放入Redis
        redisTemplate.opsForValue().set(RedisConstant.USER_LOGIN_KEY_PREFIX + token,
                driverId.toString(),
                RedisConstant.USER_LOGIN_KEY_TIMEOUT,
                TimeUnit.SECONDS);

        return token;
    }

    /**
     * 获取司机登录信息
     *
     * @return 司机信息
     */
    @Override
    public DriverLoginVo getDriverInfo() {
        Long userId = AuthContextHolder.getUserId();
        return driverInfoFeignClient.getDriverInfo(userId).getData();
    }

    /**
     * 获取司机认证信息
     *
     * @param driverId 司机id
     * @return 司机认证信息
     */
    @Override
    public DriverAuthInfoVo getDriverAuthInfo(Long driverId) {
        Result<DriverAuthInfoVo> authInfoVoResult = driverInfoFeignClient.getDriverAuthInfo(driverId);
        return authInfoVoResult.getData();
    }

    /**
     * 更新司机认证信息
     *
     * @param updateDriverAuthInfoForm 更新司机认证信息表单
     * @return 是否成功
     */
    @Override
    public Boolean updateDriverAuthInfo(UpdateDriverAuthInfoForm updateDriverAuthInfoForm) {
        Result<Boolean> booleanResult = driverInfoFeignClient.UpdateDriverAuthInfo(updateDriverAuthInfoForm);
        return booleanResult.getData();
    }
}
